@@ -17,6 +17,18 @@ Options:
 import sys, kista, docopt
 
 def f(x):
+    if x == 'true':
+        return True
+    if x == 'false':
+        return False
+    if x == 'null':
+        return None
+    if x.startswith('~'):
+        try:    return -int(x[1:])
+        except: pass
+        try:    return -float(x[1:])
+        except: pass
+        pass
     try:    return int(x)
     except: pass
     try:    return float(x)
@@ -26,7 +38,7 @@ def f(x):
 def main():
     arguments = docopt.docopt(__doc__, version=kista.version)
 
-    w3 = kista.w3_connect(0)
+    w3 = kista.w3_connect(None)
 
     if not w3.isConnected():
         print("no connection")
@@ -36,7 +48,6 @@ def main():
 
         name = arguments['<contract_name>']
         args = [f(x) for x in arguments['<args>']]
-
         x = kista.deploy_contractAddress(name, *args)
         print(x)
     
